.. Global includes, substitutions, and common links.

.. |author_name| replace:: Yesudeep Mangalapilly
.. |author_email| replace:: yesudeep@gmail.com
.. |copyright| replace:: Copyright (C) 2010 Yesudeep Mangalapilly.
.. |project_name| replace:: ``pathtools``
.. |project_version| replace:: 0.1.1

.. _issue tracker: http://github.com/gorakhargosh/pathtools/issues
.. _code repository: http://github.com/gorakhargosh/pathtools
.. _mailing list: http://groups.google.com/group/watchdog-python

.. _coverage: http://nedbatchelder.com/code/coverage/
.. _git: http://git-scm.org/
.. _github: http://github.com/
.. _nose: http://somethingaboutorange.com/mrl/projects/nose/0.11.2/
.. _pip: http://pypi.python.org/pypi/pip
.. _Python: http://python.org
.. _sphinx: http://sphinx.pocoo.org/
.. _zc.buildout: http://www.buildout.org/
